#######################################
# A python script to read in a text file
# of rainfall data for summer and winter
# within the UK and display as a plot.
# Author: <YOUR NAME>
# Email: <YOUR EMAIL>
# Date: DD/MM/YYYY
# Version: 1.0
#######################################

from matplotlib import pylab as plt
import os.path
import sys

class PlotRainfall (object):
    
    # Parse the input file - Three columns year, summer, winter
    def parseDataFile(self, dataFile, year, summer, winter):
        line = 0
        for eachLine in dataFile:
            commaSplit = eachLine.split(',', eachLine.count(','))
            first = True
            for token in commaSplit:
                if first:
                    first = False
                else:
                    if line == 0:
                        year.append(int(token))
                    elif line == 1:
                        summer.append(float(token))
                    elif line == 2:
                        winter.append(float(token))
            line += 1
    
    # Plot data onto the same axis'
    def plotData(self, year, summer, winter, outFile):
        plt.figure()
        plt.plot(year, summer)
        plt.plot(year, winter)
        plt.legend(['Summer', 'Winter'])
        plt.xlabel('Year')
        plt.ylabel('Rainfall (5 Year Mean)')
        plt.title('Summer and Winter rainfall across the UK')
        # save plot to disk.
        plt.savefig(outFile, dpi=200, format='PDF')

    # Plot the data onto separate axis, using subplot.
    def plotDataSeparate(self, year, summer, winter, outFile):
        plt.figure()
        plt.subplot(2,1,1)
        plt.plot(year, summer)
        plt.ylabel('Rainfall (5 Year Mean)')
        plt.title('Summer rainfall across the UK')
        plt.axis('tight')

        plt.subplot(2,1,2)
        plt.plot(year, winter)
        plt.xlabel('Year')
        plt.ylabel('Rainfall (5 Year Mean)')
        plt.title('Winter rainfall across the UK')
        plt.axis('tight')
        # save plot to disk.
        plt.savefig(outFile, dpi=200, format='PDF')
    
    def run(self):
        filename = 'ukweatheraverage.csv' 
        if os.path.exists(filename):
            year = list()
            summer = list()
            winter = list()
            try:
                dataFile = open(filename, 'r') 
            except IOError as e:
                print('\nCould not open file:\n', e)
                return
            self.parseDataFile(dataFile, year, summer, winter)
            dataFile.close()
            self.plotData(year, summer, winter, "Rainfall_SinglePlot.pdf")
            self.plotDataSeparate(year, summer, winter, "Rainfall_MultiplePlots.pdf")
        else:
            print('File \'' + filename + '\' does not exist.')
    
if __name__ == '__main__':
    obj = PlotRainfall()
    obj.run()
