#!/usr/bin/env python

# Import the system library
import sys
# Import the python Argument parser
import argparse
# Import the RIOS applier interface
from rios import applier
# Import the RIOS progress feedback
from rios import cuiprogress
# Import the numpy library
import numpy

# Define the applier function
def mutliplyByValue(info, inputs, outputs):
    # Convert the input data to Float32
    # This is because the output is a float due to the 
    # divide within the NDVI calculation.
    inputs.image1 = inputs.image1.astype (numpy.float32)
    inputs.image2 = inputs.image2.astype (numpy.float32)
    # Calculate the NDVI for the block.
    # Note. Numpy will deal with the image iterating
    #       to all the individual pixels values.
    #       within python this is very important 
    #       as python loops are slow.
    outputs.outimage = ((inputs.image2-inputs.image1) 
                       /
                       (inputs.image2+inputs.image1))

# This is the first part of the script to 
# be executed.
if __name__ == '__main__':
    # Create the command line options 
    # parser.
    parser = argparse.ArgumentParser()
    # Define the argument for specifying the output file.
    parser.add_argument("-o", "--output", type=str, 
                        help="Specify the output image file.")
    # Define the argument for specifying the red image band
    parser.add_argument("-r", "--red", type=str, 
                        help="Specifiy red input image file.")
    # Define the argument for specifying the NIR image band
    parser.add_argument("-n", "--nir", type=str, 
                        help="Specifiy NIR input image file.")
    # Call the parser to parse the arguments.
    args = parser.parse_args()
    
    # Check that the red input parameter has been specified.
    if args.red == None:
        # Print an error message if not and exit.
        print("Error: No red input image file provided.")
        sys.exit()
    
    # Check that the NIR input parameter has been specified.
    if args.red == None:
        # Print an error message if not and exit.
        print("Error: No NIR input image file provided.")
        sys.exit()
        
    # Check that the output parameter has been specified.
    if args.output == None:
        # Print an error message if not and exit.
        print("Error: No output image file provided.")
        sys.exit()
    
    # Create input files file names associations
    infiles = applier.FilenameAssociations()
    # Set images to the input image specified
    infiles.image1 = args.red
    infiles.image2 = args.nir
    # Create output files file names associations
    outfiles = applier.FilenameAssociations()
    # Set outImage to the output image specified
    outfiles.outimage = args.output
    # Create a controls objects
    aControls = applier.ApplierControls()
    # Set the progress object.
    aControls.progress = cuiprogress.CUIProgressBar()
    
    # Apply the multiply function.
    applier.apply(mutliplyByValue, 
                  infiles, 
                  outfiles, 
                  controls=aControls)
 