#!/usr/bin/env python

# Import the system library
import sys
# import the rat module from rios
from rios import rat
# import numpy
import numpy
# import gdal
import osgeo.gdal as gdal
# Import the python Argument parser
import argparse

# A function for 
def colourLevel3(classLevel3):
    # Create the empty output arrays and set them 
    # so they all have a value of 0 other than 
    # opacity which is 255 to create solid colours 
    level3red = numpy.empty_like(classLevel3, dtype=numpy.int)
    level3red[...] = 0
    level3green = numpy.empty_like(classLevel3, dtype=numpy.int)
    level3green[...] = 0
    level3blue = numpy.empty_like(classLevel3, dtype=numpy.int)
    level3blue[...] = 0
    level3alpha = numpy.empty_like(classLevel3, dtype=numpy.int)
    level3alpha[...] = 255
    
    # For segmentation of class NA set them to be black
    level3red = numpy.where(classLevel3 == "NA", 0, level3red)
    level3green = numpy.where(classLevel3 == "NA", 0, level3green)
    level3blue = numpy.where(classLevel3 == "NA", 0, level3blue)
    level3alpha = numpy.where(classLevel3 == "NA", 255, level3alpha)
    
    # Colour Cultivated Terrestrial Vegetated
    level3red = numpy.where(classLevel3 == "Cultivated Terrestrial Vegetated", 
                            192, level3red)
    level3green = numpy.where(classLevel3 == "Cultivated Terrestrial Vegetated", 
                              255, level3green)
    level3blue = numpy.where(classLevel3 == "Cultivated Terrestrial Vegetated", 
                             0, level3blue)
    level3alpha = numpy.where(classLevel3 == "Cultivated Terrestrial Vegetated",  
                              255, level3alpha)
    
    # Colour Natural Terrestrial Vegetated
    level3red = numpy.where(classLevel3 == "Natural Terrestrial Vegetated", 
                            0, level3red)
    level3green = numpy.where(classLevel3 == "Natural Terrestrial Vegetated", 
                              128, level3green)
    level3blue = numpy.where(classLevel3 == "Natural Terrestrial Vegetated", 
                             0, level3blue)
    level3alpha = numpy.where(classLevel3 == "Natural Terrestrial Vegetated", 
                              255, level3alpha)
    
    # Colour Cultivated Aquatic Vegetated
    level3red = numpy.where(classLevel3 == "Cultivated Aquatic Vegetated", 
                            0, level3red)
    level3green = numpy.where(classLevel3 == "Cultivated Aquatic Vegetated", 
                              255, level3green)
    level3blue = numpy.where(classLevel3 == "Cultivated Aquatic Vegetated", 
                             255, level3blue)
    level3alpha = numpy.where(classLevel3 == "Cultivated Aquatic Vegetated", 
                              255, level3alpha)
    
    # Colour Natural Aquatic Vegetated
    level3red = numpy.where(classLevel3 == "Natural Aquatic Vegetated", 
                            0, level3red)
    level3green = numpy.where(classLevel3 == "Natural Aquatic Vegetated", 
                              192, level3green)
    level3blue = numpy.where(classLevel3 == "Natural Aquatic Vegetated", 
                             122, level3blue)
    level3alpha = numpy.where(classLevel3 == "Natural Aquatic Vegetated", 
                              255, level3alpha)
    
    # Colour Artificial Surface
    level3red = numpy.where(classLevel3 == "Artificial Surface", 
                            255, level3red)
    level3green = numpy.where(classLevel3 == "Artificial Surface", 
                              0, level3green)
    level3blue = numpy.where(classLevel3 == "Artificial Surface", 
                             255, level3blue)
    level3alpha = numpy.where(classLevel3 == "Artificial Surface", 
                              255, level3alpha)
    
    # Colour Natural Surface
    level3red = numpy.where(classLevel3 == "Natural Surface", 
                            255, level3red)
    level3green = numpy.where(classLevel3 == "Natural Surface", 
                             192, level3green)
    level3blue = numpy.where(classLevel3 == "Natural Surface", 
                             160, level3blue)
    level3alpha = numpy.where(classLevel3 == "Natural Surface", 
                              255, level3alpha)
    
    # Colour Artificial Water
    level3red = numpy.where(classLevel3 == "Artificial Water", 
                            0, level3red)
    level3green = numpy.where(classLevel3 == "Artificial Water", 
                              0, level3green)
    level3blue = numpy.where(classLevel3 == "Artificial Water", 
                             255, level3blue)
    level3alpha = numpy.where(classLevel3 == "Artificial Water", 
                              255, level3alpha)
    
    # Colour Natural Water
    level3red = numpy.where(classLevel3 == "Natural Water", 
                            0, level3red)
    level3green = numpy.where(classLevel3 == "Natural Water", 
                              0, level3green)
    level3blue = numpy.where(classLevel3 == "Natural Water", 
                             255, level3blue)
    level3alpha = numpy.where(classLevel3 == "Natural Water", 
                              255, level3alpha)
    
    return level3red, level3green, level3blue, level3alpha

# This is the first part of the script to 
# be executed.
if __name__ == '__main__':
    # Create the command line options parser.
    parser = argparse.ArgumentParser()
    # Define the argument for specifying the input file.
    parser.add_argument("-i", "--input", type=str, 
                        help="Specify the input image file.")
    # Call the parser to parse the arguments.
    args = parser.parse_args()
    
    # Check that the input parameter has been specified.
    if args.input == None:
        # Print an error message if not and exit.
        print("Error: No input image file provided.")
        sys.exit()
    
    # Open the input file using GDAL
    ratDataset = gdal.Open(args.input, gdal.GA_Update)
    
    # Check that is openned correctly
    if not ratDataset == None:
        # Print some user feedback
        print("Import Columns.")
        # Read the classification column
        level3 = rat.readColumn(ratDataset, "ClassLevel3")
        
        # Print some user feedback
        print("Classifying Level 3")
        # Call function to assign colours to arrays
        level3red, level3green, level3blue, level3alpha = colourLevel3(level3)
        # Write the values to the Output Columns 
        rat.writeColumn(ratDataset, "Red", level3red)
        rat.writeColumn(ratDataset, "Green", level3green)
        rat.writeColumn(ratDataset, "Blue", level3blue)
        rat.writeColumn(ratDataset, "Alpha", level3alpha)
    else:
        # Print an error message to the user if the image
        # file could not be openned.
        print("Input Image could not be opened")
